<?php
namespace OrganizationsManagement\Controller;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\Messages;
use OrganizationsManagement\Util\Utilities;
use OrganizationsManagement\Util\InstanceProvider;

class CallCategory extends Simple
{
    /** @var Service\CallCategory $api */
    protected $callCategoryService;

    public function __construct(Service\CallCategory $callCategory){
        $this->callCategoryService = $callCategory;
    }

     public function findCallCategories(Request\Filter $request, Response $response)
    {
        try {
            $conditions  = $request->getFilterCriteria()->getConditions();
            $page = $request->getFilterCriteria()->getPage();
            $pageSize = $request->getFilterCriteria()->getPageSize();
            $data = $this->callCategoryService->findCallCategories($conditions, $page, $pageSize);
            $response->addDataSet(new DataSource\DataSet('findClassification', $data));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findClassification(Request\Filter $request, Response $response)
    {
        try {
            $conditions  = $request->getFilterCriteria()->getConditions();
            $page = $request->getFilterCriteria()->getPage();
            $pageSize = $request->getFilterCriteria()->getPageSize();
            $data = $this->callCategoryService->findClassification($conditions, $page, $pageSize);
            $response->addDataSet(new DataSource\DataSet('findaAssunto', $data));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveCallCategory(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $classificationId = $requestRow["ID"];
            $cdAssunto = $requestRow["CDASSUNTO"];
            $data = $this->callCategoryService->saveClassificationCdAssunto($classificationId, $cdAssunto);
            $response->addDataSet(new DataSource\DataSet('findaAssunto', [$data]));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

}
