<?php

namespace OrganizationsManagement\Controller;

use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Util\InstanceProvider;

class Commands
{
    /**
     * @param DTO\Request\Filter $request
     * @param DTO\Response $response
     */
    public function findCommands(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filters   = $request->getFilterCriteria()->getConditions();
            $registers = InstanceProvider::getService()->getCommands()->findCommands($filters);
            $response->addDataSet(new DataSource\DataSet('commands', $registers));
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }

    /**
     * @param DTO\Request\DataSet $request
     * @param DTO\Response $response
     */
    public function saveCommand(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row          = $request->getDataSet()->getRows()[0];
            $id           = isset($row['ID']) ? $row['ID'] : null;
            $dscomandoest = $row['DSCOMANDOEST'];
            $nrordem      = $row['NRORDEM'];
            $comando      = $row['COMANDO'];
            $idtpcomando  = $row['IDTPCOMANDO'];
            $idambcomando = $row['IDAMBCOMANDO'];
            $idacaoexecom = $row['IDACAOEXECOM'];
            $idativo      = $row['IDATIVO'];
            $result       = InstanceProvider::getService()->getCommands()->saveCommand($id, $dscomandoest, $nrordem, $comando, $idtpcomando,
                                                                                       $idambcomando, $idacaoexecom, $idativo);
            $response->addDataSet(new DataSource\DataSet('command', $result));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    /**
     * @param DTO\Request\Row $request
     * @param DTO\Response $response
     */
    public function removeCommand(DTO\Request\Row $request, DTO\Response $response){
        try {
            $requestRow = $request->getRow();
            $id = $requestRow['ID'];
            InstanceProvider::getService()->getCommands()->removeCommand($id);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }

    /**
     * @param DTO\Request\Filter $request
     * @param DTO\Response $response
     */
    public function findCommandUrls(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filters   = $request->getFilterCriteria()->getConditions();
            $commandId = Utilities::getValueInFilterDataSourceByName($filters, 'COMMAND_ID', true);
            $registers = InstanceProvider::getService()->getCommands()->findCommandUrls($commandId, $filters);
            $response->addDataSet(new DataSource\DataSet('commandUrls', $registers));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }

    /**
     * @param DTO\Request\DataSet $request
     * @param DTO\Response $response
     */
    public function saveCommandUrl(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row       = $request->getDataSet()->getRows()[0];
            $id        = isset($row['ID']) ? $row['ID'] : null;
            $commandId = $row['COMANDO_ESTRUTURA_ID'];
            $url       = $row['DSWEBSERVICEURL'];
            $idativo   = $row['IDATIVO'];
            $result    = InstanceProvider::getService()->getCommands()->saveCommandUrl($id, $commandId, $url, $idativo);
            $response->addDataSet(new DataSource\DataSet('command', $result));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    /**
     * @param DTO\Request\Row $request
     * @param DTO\Response $response
     */
    public function removeCommandUrl(DTO\Request\Row $request, DTO\Response $response){
        try {
            $requestRow = $request->getRow();
            $id = $requestRow['ID'];
            InstanceProvider::getService()->getCommands()->removeCommandUrl($id);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }

    /**
     * @param DTO\Request\DataSet $request
     * @param DTO\Response $response
     */
    public function saveMultipleCommandUrl(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row      = $request->getDataSet()->getRows()[0];
            $commands = $row['COMMANDS'];
            $url      = $row['URLS'];
            InstanceProvider::getService()->getCommands()->saveMultipleCommandUrl($commands, $url);
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    /**
     * @param DTO\Request\DataSet $request
     * @param DTO\Response $response
     */
    public function copyCommands(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row     = $request->getDataSet()->getRows()[0];
            $origin  = $row['ORIGIN_IDAMBCOMANDO'];
            $destiny = $row['DESTINY_IDAMBCOMANDO'];
            InstanceProvider::getService()->getCommands()->copyCommands($origin, $destiny);
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}