<?php
namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Teknisa\Entities;
use OrganizationsManagement\Util\Utilities;
use Util\Messages;
use OrganizationsManagement\Util;
use OrganizationsManagement\Util\InstanceProvider;
use Teknisa\Model\Geral\Repositories as GeralRepositories;
use Teknisa\Libs\Util\Environment as TeknisaEnvironment;

class ScoreReport
{

    const TYPE_ISSUE        = Entities\CpCall::TYPE_ISSUE;
    const TYPE_CASO         = Entities\CpCall::TYPE_CASO;
    const TYPE_RICH_CLIENT  = Entities\CpCall::TYPE_RICH_CLIENT;
    const TYPE_TICKET       = Entities\CpCall::TYPE_TICKET;

    protected $orderReverse = false;
    protected $orderBy = 'ID';

    const MAIN_TYPE_OF_PRODUCT_CALL = "P";
    const MAIN_TYPE_OF_SUPPORT_CALL = "S";

    /** @var EntityManager $entityManager */
    protected $entityManager;
    /** @var TeknisaEnvironment **/
    protected $environment;
    /** @var GeralRepositories\CpCall */
    protected $cpCallRepository;
    /** @var GeralRepositories\Operador  */
    private $repositoryOperador;
    /** @var \Teknisa\Model\Teknisa\Repositories\OmProduto  */
    private $omProdutoRepository;

    public function __construct(EntityManager $entityManager, TeknisaEnvironment $environment) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;

        $this->cpCallRepository = $this->entityManager->getRepository(Utilities::TEKNISA_ENTITY_DIR . 'CpCall');
        $this->repositoryOperador = $this->entityManager->getRepository(Utilities::GERAL_ENTITY_DIR . 'Operador');
        $this->faturamentoRepository = $this->entityManager->getRepository(Utilities::GERAL_ENTITY_DIR . 'Parcnegocio');
        $this->omProdutoRepository = $this->entityManager->getRepository(Utilities::TEKNISA_ENTITY_DIR . 'OmProduto');
    }

    public function findCalls($mainType, $conditions, $orderBy, $page, $pageSize, $groupByLabel = 'N', $orgId)
    {
        $limit = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        $userId           = $this->environment->getCurrentUserId();
        $situationFilters = $this->getAllSituationDividedByType();



        if($orderBy){
            $this->orderReverse = current($orderBy) == 'ASC';
            $orderByName        = key($orderBy);
            $this->orderBy      = $orderByName;
            $orderBy            = "CALL." . $orderByName ." ". current($orderBy);
        } else {
            $orderBy = "CALL.UPDATED_AT DESC";
        }
        $orderBy .= " NULLS LAST";

        $customQuery = $this->getQueryAllCall($conditions, $mainType, $situationFilters, $orgId);

        $result = array();
        if($customQuery){
            $result  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->findAllCalls($customQuery, $situationFilters,  $userId,  $offset, $limit, $orderBy, $groupByLabel);
        }
        return $result;
    }

    public function getAllSituationDividedByType($eliasSoliserv = 'SER')
    {
        $waitingTicket = Utilities::getWaitingTicket();
        $cdClienteBase = Utilities::getCdClienteBase();
        $allSituation  = Util\InstanceProvider::getRepository()->getOmParcnegocio()->getAllSituation($this->environment->getCurrentOrganizationId(),$waitingTicket);
        list($openedGep, $closedGep) = $this->getBeginAndEndCdfasetram();

        $waitingGEP = " (EXISTS (SELECT CDOPERADOR FROM OPERADOR WHERE CDCLIENTE <> '$cdClienteBase' AND CDOPERADOR = $eliasSoliserv.CDOPERRESP " ;

        $allSituationDividedByType = array(
            'GEP' => [
                'CLOSED' => " $eliasSoliserv.CDFASETRAM = $closedGep OR ($eliasSoliserv.IDSOLIENCE = 'S')",
                'OPENED' => " $eliasSoliserv.CDFASETRAM = $openedGep AND ($eliasSoliserv.IDSOLIENCE <> 'S')",
                'WAITING' => " $waitingGEP AND $eliasSoliserv.CDFASETRAM NOT IN ($closedGep) AND ($eliasSoliserv.IDSOLIENCE <> 'S'))) ",
                'IN_PROGRESS' => " $eliasSoliserv.CDFASETRAM NOT IN ($openedGep,$closedGep) AND ($eliasSoliserv.IDSOLIENCE <> 'S') ",
            ],
            'PM' => [
                'CLOSED' => [],
                'OPENED' => [],
                'WAITING' => [],
                'IN_PROGRESS' => [],
            ],
            'CRM' => [
                'CLOSED' => [],
                'OPENED' => [],
                'WAITING' => [],
                'IN_PROGRESS' => [],
            ],
        );
        foreach ($allSituation as $situation) {
            $allSituationDividedByType[$situation['PRODUCT']][$situation['SITUATION']][] = $situation['ID'];
        }
        return $allSituationDividedByType;
    }

    public function getBeginAndEndCdfasetram()
    {
        $paramgeral = $this->cpCallRepository->getBeginAndEndCdfasetram($this->environment->getCurrentOrganizationId());
        return array($paramgeral['CDFATRAMIWEB'],$paramgeral['CDFATRAMENCE']);
    }

    public function getQueryAllCall($conditions, $mainType, $situationFilters, $orgId)
    {
        list($callType, $whereFiltersProductCalls, $situationProductCalls, $specialFiltersProductCalls) = $this->buildWhereFilterToProductCalls($conditions);


        $queryPmCalls = $queryIntranetCalls = $queryCrmCalls = "";

        if ($mainType == self::MAIN_TYPE_OF_PRODUCT_CALL) {
            if ($callType == self::TYPE_ISSUE) {
                $queryPmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryPmCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['ISSUE'], $whereFiltersProductCalls, $orgId);

            } else if ($callType == self::TYPE_RICH_CLIENT) {
                $queryPmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryIntranetCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['SOLISERV'], $whereFiltersProductCalls, $orgId);

            } else if ($callType == self::TYPE_TICKET) {

            } else {
                $queryPmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryPmCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['ISSUE'], $whereFiltersProductCalls, $orgId);
                $queryIntranetCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryIntranetCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['SOLISERV'], $whereFiltersProductCalls, $orgId);

            }
        } else if ($mainType == self::MAIN_TYPE_OF_SUPPORT_CALL) {
            if ($callType == self::TYPE_TICKET) {
                $queryCrmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryTicketCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['CONTATO'], $whereFiltersProductCalls, $orgId);
            } else if ($callType == self::TYPE_RICH_CLIENT || $callType == self::TYPE_ISSUE) {

            } else {
                $queryCrmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryTicketCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['CONTATO'], $whereFiltersProductCalls, $orgId);

            }
        } else {
            $queryPmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryPmCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['ISSUE'], $whereFiltersProductCalls, $orgId);
            $queryIntranetCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryIntranetCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['SOLISERV'], $whereFiltersProductCalls, $orgId);
            $queryCrmCalls  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getQueryTicketCalls($situationFilters, $specialFiltersProductCalls, $situationProductCalls['CONTATO'], $whereFiltersProductCalls, $orgId);
        }

        $customQuery = $queryPmCalls;



        if ($queryIntranetCalls) {
            $customQuery .= (empty($customQuery) ? "" : " UNION ") . $queryIntranetCalls;
        }

        if ($queryCrmCalls) {
            $customQuery .= (empty($customQuery) ? "" : " UNION ") . $queryCrmCalls;
        }
        return $customQuery;
    }

    private function buildWhereFilterToProductCalls($conditions)
    {
        $specialFilters = '';
        $callType = '';
        $situation = array(
            'ISSUE' =>'',
            'CONTATO' =>'',
            'SOLISERV' =>'',
        );
        foreach($conditions as $key => $filter) {
            if($filter['columnName'] == 'PRODUCT_TYPE') {
                $specialFilters .= " AND EXISTS(SELECT * FROM SOLISERV SOLIC WHERE SOLIC.CDPRODGRUP = ";
                $specialFilters .= "'". $filter['value'] . "' AND SOLIC.NRSOLISERV = C.CALL_RELATIONSHIP)";
                unset($conditions[$key]);
            } else if($filter['columnName'] == 'CALL_WITHOUT_LABELS_CHECK') {
                if($filter['value'] == '%Y%') {
                    $userId = $this->environment->getCurrentUserId();
                    $specialFilters .= " AND NOT EXISTS(SELECT CLR.CALL FROM CP_CALL_LABEL_RELATION CLR WHERE CLR.CALL = C.NRCALL AND CLR.LABEL IN (SELECT NRCALLLABEL FROM CP_CALL_LABEL WHERE CDOPERINCLUSAO = '$userId') OR CLR.LABEL IS NULL)";
                }
                unset($conditions[$key]);
            } else if($filter['columnName'] == 'CALL_LABELS') {
                $conditions[$key]["columnName"] = "CLR.LABEL";
                $specialFilters .= "AND EXISTS(SELECT CLR.CALL FROM CP_CALL_LABEL_RELATION CLR WHERE CLR.CALL = C.NRCALL AND CLR.LABEL IN(".implode(',',$filter['value'])."))";
                unset($conditions[$key]);
            } else if($filter['columnName'] == 'TYPE') {
                $callType = $conditions[$key]['value'];
                unset($conditions[$key]);
            } else if($filter['columnName'] == 'STATUS') {
                $situation = $this->situationFilter($conditions[$key]['value']);
                unset($conditions[$key]);
            } else if($filter['columnName'] == 'NRCALL'){
                $conditions[$key]['columnName'] = 'ID';
            } else if($filter['columnName'] == 'CLASSIFICATION_NAME'){
                $conditions[$key]['columnName'] = 'CLASSIFICATION';
            }
        }
        $conditionsQuery = Utilities::createQueryFiltered($conditions);

        return array($callType, $conditionsQuery, $situation, $specialFilters);
    }

    public function situationFilter($situationTypes, $eliasContato = 'CONT', $eliasTaskStattus = 'TS', $eliasSoliserv = 'SER')
    {
        $situationFilter = array(
            'ISSUE' =>'',
            'CONTATO' =>'',
            'SOLISERV' =>'',
        );
        if(!empty($situationTypes)){
            $issue = array();
            $contato = array();
            $soliserv  = array();
            asort($situationTypes);
            $isWaitingIssue= '';
            $allSituationDividedByType = $this->getAllSituationDividedByType($eliasSoliserv);
            foreach ($situationTypes as $situationType) {
                if ($situationType == Entities\CpCall::CLOSE_SITUATION) {
                    $issue = $allSituationDividedByType['PM']['CLOSED'];
                    $contato = $allSituationDividedByType['CRM']['CLOSED'];
                    $soliserv[] = $allSituationDividedByType['GEP']['CLOSED'];
                } else if ($situationType == Entities\CpCall::OPEN_SITUATION) {
                    $issue = array_merge($issue,$allSituationDividedByType['PM']['OPENED']);
                    $contato = array_merge($contato,$allSituationDividedByType['CRM']['OPENED']);
                    $soliserv[] = $allSituationDividedByType['GEP']['OPENED'];
                } else  if ($situationType == Entities\CpCall::PROGRESS_SITUATION) {
                    $issue = array_merge($issue,$allSituationDividedByType['PM']['IN_PROGRESS']);
                    $contato = array_merge($contato,$allSituationDividedByType['CRM']['IN_PROGRESS']);
                    $soliserv[] = $allSituationDividedByType['GEP']['IN_PROGRESS'];
                } else if ($situationType == Entities\CpCall::WAITING_SPONSOR_SITUATION) {
                    $issue = array_merge($issue,$allSituationDividedByType['PM']['WAITING']);
                    $contato = array_merge($contato,$allSituationDividedByType['CRM']['WAITING']);
                    $soliserv[] = $allSituationDividedByType['GEP']['WAITING'];
                    $isWaitingIssue = true;
                }
            }
            $question = <<<SQL
                         'Q' = (SELECT NVL(CONTROL,'I') FROM (SELECT CTY.CONTROL
                                                FROM COMMENTS COM
                                                LEFT JOIN COMMENT_TYPE CTY ON(COM.COMMENT_TYPE_ID = CTY.ID )
                                                WHERE COM.TASK = TAS.ID
                                                ORDER BY COM.ID DESC)
                                                WHERE ROWNUM = 1 )
SQL;

            if(!empty($issue)){
                $contatoString = implode($contato, ',');
                $issueString = implode($issue, ',');
                $soliservString = implode($soliserv, 'OR');
                $situationFilter['CONTATO'] = " AND $eliasContato.NRSEQSITUACAO IN($contatoString)";
                $situationFilter['SOLISERV'] = " AND ($soliservString)";

                if($isWaitingIssue){
                    $situationFilter['ISSUE'] = " AND ($eliasTaskStattus.ID IN($issueString) OR $question )";
                }else{
                    $situationFilter['SOLISERV'] .= "AND NOT ".$allSituationDividedByType['GEP']['WAITING'];
                    $situationFilter['ISSUE'] = " AND $eliasTaskStattus.ID IN($issueString)"." AND NOT ".$question;
                }
            }
        }
        return $situationFilter;
    }

    public function findAllOperadorRelationshipCliente($condition, $page = 0, $pageSize = 0){
        $cdCliente = Utilities::getCdClienteBase();
        $userId    = $this->environment->getCurrentUserId();
        $filter    = Utilities::createQueryFiltered($condition);
        $finalPos  = $pageSize*$page;
        $startPos  = $pageSize == 0 ? 0 : $finalPos-($pageSize-1);
        return $this->repositoryOperador->findAllOperadorRelationshipCliente($cdCliente, $userId, $filter, $startPos, $finalPos);
    }

    public function findAllOperadorResponsible($condition, $page, $pageSize){
        $filter    = Utilities::createQueryFiltered($condition);
        $filterTeknisa = "";
        $userId = $this->environment->getCurrentUserId();
        $teknisaId = Utilities::getCdClienteBase();

        if(!Utilities::currentUserIsTeknisa()){
            $filterTeknisa = "AND OP.CDCLIENTE IN (
            SELECT CDCLIENTE
            FROM(
                SELECT CLI.CDCLIENTE
                FROM OPERCLIE OCL
                JOIN OPERADOR OPE ON (OCL.CDOPERADOR  = OPE.CDOPERADOR AND OPE.CDOPERADOR = '". $userId ."')
                JOIN CLIENTE CLI ON (CLI.CDCLIENTE = OCL.CDCLIENTE AND CLI.IDATIVO = 'S'))
                UNION
                (SELECT CLI.CDCLIENTE
                FROM OPERADOR OPE
                JOIN CLIENTE CLI ON (CLI.CDCLIENTE = OPE.CDCLIENTE AND CLI.IDATIVO = 'S')
                WHERE OPE.CDOPERADOR = '". $userId ."')
                UNION
                SELECT '". $teknisaId ."' AS CDCLIENTE FROM DUAL
           ) ";
        }
        $finalPos  = $pageSize*$page;
        $startPos  = $pageSize == 0 ? 0 : $finalPos-($pageSize-1);
        return $this->repositoryOperador->findAllOperadorResponsible($filter, $filterTeknisa, $finalPos, $startPos);
    }

    /**
     * @param $conditions
     * @param $nrorg
     * @param $nrparcnegocio
     * @param $dtinicompet
     * @param $dtfincompet
     * @return array
     */
    public function faturamento($conditions, $nrparcnegocio, $dtinicompet, $dtfincompet, $page, $pageSize, $orderBy = null)
    {
        $limit = $page * $pageSize;
        
        $nrorg = $this->environment->getCurrentOrganizationId();
        $orderString = 'ORDER BY DTINICOMPET ASC, NRSEQCONTRATO';
        $offset = ($page - 1) * $pageSize;
        foreach($conditions as &$condition){
            if($condition["columnName"] == "DTFINCOMPET"){
                $condition["operator"] = "<=";
                $condition['value'] = "'" . $condition['value'] . "'";
            }
            if($condition["columnName"] == "DTINICOMPET"){
                $condition["operator"] = ">=";
                $condition['value'] = "'" . $condition['value'] . "'";
            }
        }
        $filter = Utilities::createQueryFiltered($conditions);
        if($orderBy){
            foreach($orderBy as $idx => $order) {
                $orderString = 'ORDER BY ' . $idx . ' ' . $order;
            }
        }
        $dtinicompetFilter = '';
        $dtfincompetFilter = '';
        $dtinicompetFilterMed = '';
        $dtfincompetFilterMed = '';
        if($dtinicompet){
            $dtinicompetFilter = "AND (TRUNC(TO_DATE('{$dtinicompet}', 'DD/MM/YYYY')) < TRUNC(FAT.DTINICOMPET) OR TRUNC(TO_DATE('{$dtinicompet}', 'DD/MM/YYYY')) < TRUNC(FAT.DTFINCOMPET))";
            $dtinicompetFilterMed = "AND (TRUNC(TO_DATE('{$dtinicompet}', 'DD/MM/YYYY')) < TRUNC(MED.DTINICOMPET) OR TRUNC(TO_DATE('{$dtinicompet}', 'DD/MM/YYYY')) < TRUNC(MED.DTFINCOMPET))";
        }
        if($dtfincompet){
            $dtfincompetFilter = "AND (TRUNC(TO_DATE('{$dtfincompet}', 'DD/MM/YYYY')) > TRUNC(FAT.DTINICOMPET) OR TRUNC(TO_DATE('{$dtfincompet}', 'DD/MM/YYYY')) > TRUNC(FAT.DTFINCOMPET))";
            $dtfincompetFilterMed = "AND (TRUNC(TO_DATE('{$dtfincompet}', 'DD/MM/YYYY')) > TRUNC(MED.DTINICOMPET) OR TRUNC(TO_DATE('{$dtfincompet}', 'DD/MM/YYYY')) > TRUNC(MED.DTFINCOMPET))";
        }
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getFaturamentoContrato($filter, $dtinicompetFilter, $dtfincompetFilter, $dtinicompetFilterMed, $dtfincompetFilterMed, $nrorg, $nrparcnegocio, $limit, $offset, $orderString);
    }

    public function getContratosForScore($nrparcnegocio) {
        $nrorg = $this->environment->getCurrentOrganizationId();
        $aditionalValues =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getFinancialForScore($nrorg, $nrparcnegocio);
        $mainScore = Util\InstanceProvider::getRepository()->getOmParcnegocio()->getContratosForScore($nrorg, $nrparcnegocio);
        $mainScore[0]["EXPIRED"] = $aditionalValues[0]["EXPIRED"];
        $mainScore[0]["OPENED"] = $aditionalValues[0]["OPENED"];
        return $mainScore;
        
    }

    public function getItensContrato($nrfaturacont, $nrorg, $nrparcnegocio, $conditions){
        $filter = Utilities::createQueryFiltered($conditions);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getItensContrato($nrfaturacont, $nrorg, $nrparcnegocio, $filter);
    }

    public function getItemsOrcamento($nrorg, $idadicitemorc, $nrseqcontrato, $nrseqorcamento){
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getItemsOrcamento($nrorg, $idadicitemorc, $nrseqcontrato, $nrseqorcamento);
    }

    public function getNegociacaoContratoCompleto($nrseqcontrato, $filters){
        $filter = Utilities::createQueryFiltered($filters);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getNegociacaoContratoCompleto($nrseqcontrato, $filter);
    }

    public function getCompetenciaNegoCont($filters){
        $filter = Utilities::createQueryFiltered($filters);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getCompetenciaNegoCont($filter);
    }

    public function getParcelanegocont($filters){
        $filter = Utilities::createQueryFiltered($filters);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getParcelanegocont($filter);
    }

    public function getDescperiodonegocont_negociacaocontrato($filters){
        $filter = Utilities::createQueryFiltered($filters);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getDescperiodonegocont_negociacaocontrato($filter);
    }

    public function getElements($nrorg, $idescolhido, $nrseqorcamento, $conditions){
        $filter = Utilities::createQueryFiltered($conditions);
        if(!$nrseqorcamento){
            return false;
        }
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getElements($nrorg, $idescolhido, $nrseqorcamento, $filter);
    }
    
    public function getEscopoTIpoOrcamento($conditions, $page, $pageSize, $orderBy){
        $orderString= "";
        $filter = Utilities::createQueryFiltered($conditions);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        if($orderBy){
            foreach($orderBy as $idx => $order) {
                $orderString = 'ORDER BY ' . $idx . ' ' . $order;
            }
        }
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getEscopoTIpoOrcamento($filter, $limit, $offset, $orderString);
    }

    public function getContratos($conditions, $nrparcnegocio, $isFilter, $page, $pageSize , $orderBy){
        $nrorg = $this->environment->getCurrentOrganizationId();
        $situacaoFilter = "";
        $orderString= "";
         $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        if($orderBy){
            foreach($orderBy as $idx => $order) {
                $orderString = 'ORDER BY ' . $idx . ' ' . $order;
            }
        }
        if(!$isFilter){
            $situacaoFilter = "AND fct_contrato.idsituacaocontrato = 'A'";
        }
        foreach ($conditions as &$condition) {
            if($condition['columnName'] == "NMTIPOORCAMENTO" || $condition['columnName'] == "NRTIPOORCAMENTO"){
                $condition['columnName'] = 'ESCOPO.' . $condition['columnName'];
            }else{
                $condition['columnName'] = 'fct_contrato.' . $condition['columnName'];
            }
                
        }
        $filter = Utilities::createQueryFiltered($conditions);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->getContratos($nrorg, $filter,$nrparcnegocio, $situacaoFilter, $limit, $offset, $orderString);
    }

    /**
     * @param $conditions
     * @param $nrparcnegocio
     * @return array
     */
    public function findProdutosContratados($conditions, $nrparcnegocio)
    {
        $filter = Utilities::createQueryFiltered($conditions);
        return $this->omProdutoRepository->findProdutosContratados($filter, $nrparcnegocio);

    }

    public function getOrganizationScore($filters, $page, $pageSize, $orderBy, $isIntId = true, $isPrimary = null) {
        $conditions = Utilities::createQueryFiltered($filters);
        if($isPrimary && $isPrimary == "S"){
            $conditions .= "AND NRORGPRINCIPAL IS NOT NULL";
        } else if($isPrimary && $isPrimary == "P"){
            $conditions .= "AND NRORGPRINCIPAL IS NULL";
        }
        if(empty($orderBy)) {
            $conditions .= ' ORDER BY TO_NUMBER(NRSCORE) DESC';
        } else {
            foreach ($orderBy as $idx => $order) {
                $conditions .= ' ORDER BY ' . $idx . ' ' . $order;
            }
        }
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        $organizacoes = $this->omProdutoRepository->getOrganizationScore($conditions, $limit, $offset);
        if($isIntId) {
            foreach ($organizacoes as &$organizacao) {
                $organizacao['NRORG'] = intval($organizacao['NRORG']);
            }
        }
        return $organizacoes;
    }

    public function saveScoreReport($score, $alert, $director, $responsible, $godfather, $manager, $inProject, $nrorg){
        $operador = Utilities::getCurrentUserId();
        $dateNow = new \DateTime();
        $idaltnrscore = 'N';
        $entityManager = InstanceProvider::getEntityManager();
        $connection    = $entityManager->getConnection();
        $organizacaoEntity = InstanceProvider::getRepository()->getOrganizacao()->findOneBy(array('nrorg' => $nrorg));
        if($organizacaoEntity->getNrscore() != $score){
            $idaltnrscore = 'S';
        }
        $score = InstanceProvider::getFactory()->getOrganizacao()->saveScoreOrganization($organizacaoEntity, $operador, $score, $alert, $godfather, $manager, $inProject, $director, $responsible, $idaltnrscore);
        $this->entityManager->persist($score);
        $this->entityManager->flush();
        return $score->getNrorg();
    }
    
    public function autoUpdateNrscores() {
        $entityManager = InstanceProvider::getEntityManager();
        $organizacaoEntity = InstanceProvider::getRepository()->getOrganizacao()->findBy(array('idaltnrscore' => 'N', 'idativo' => 'S'));
        
        foreach($organizacaoEntity as $order => $org) {
            $nrparcnegocio = $org->getNrparcnegocio();
            $maintenanceType = Utilities::getMaintenanceType();
            $result = $this->omProdutoRepository->getCalculatedNrscore($nrparcnegocio, $maintenanceType);
            if(empty($result["SOMA"])) {
                $result["SOMA"] = 1;
            }
            $score = InstanceProvider::getFactory()->getOrganizacao()->saveNrScore($org, $result["SOMA"]);
            $this->entityManager->persist($score);
        }
        
        $this->entityManager->flush();
    }

    public function findCallsByType($orgId)
    {
        $situationFilters = $this->getAllSituationDividedByType();

        $result  =  Util\InstanceProvider::getRepository()->getOmParcnegocio()->findCallsByType($situationFilters, $orgId);

        return $result;
    }
    
    public function financeiro($conditions, $orderBy, $page, $pageSize,$nrparcnegocio, $vencboleto, $dtemissao, $dtvencimento, $dtpagamento)
    {
         $limit = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        $emissaoFilter = "";
        $vencFilter = "";
        $pagFilter = "";
        if($dtemissao){
            $emissaoFilter = "  AND NF.DTEMISSAO BETWEEN '" . $dtemissao[0] . "' AND '" . $dtemissao[1] . "'";
        }
        
        if($dtvencimento){
            if($vencboleto){
                $vencFilter = "AND ((CR.DTATUAVENREC < TRUNC(SYSDATE)) AND (BO.IDSTATBREC IN ('A','E')) 
                OR (CR.DTATUAVENREC BETWEEN '" . $dtvencimento[0] . "' AND '" . $dtvencimento[1] . "'))";
            }else{
                $vencFilter =  "AND CR.DTATUAVENREC BETWEEN '" . $dtvencimento[0] . "' AND '" . $dtvencimento[1] . "'";
            }
        }
        if($dtpagamento){
            $pagFilter = " AND ((BR.DTBAIXAREC BETWEEN '". $dtpagamento[0] . "' AND '" . $dtpagamento[1] ."'))";
        }
       $orderByString = '';
        foreach($orderBy as $idx => $order) {
            if($idx === 'DTATUAVENREC' || $idx === 'DTORIGVENREC' || $idx === 'DTEMISSAO' || $idx === 'DTBAIXAREC'){
                $orderByString .= ' ORDER BY TO_DATE(' . $idx . ') ' . $order . ' NULLS LAST';
            } else {
                $orderByString .= ' ORDER BY ' . $idx . ' ' . $order;
            }
        }
        $conditionsQuery = Utilities::createQueryFiltered($conditions);
        return  Util\InstanceProvider::getRepository()->getOmParcnegocio()->scoreReportGetFinanceiro($conditionsQuery, $orderByString,$nrparcnegocio, $emissaoFilter, $vencFilter, $pagFilter, $limit, $offset);
    }





}