<?php

namespace Zeedhi\ZhuAcl\Controller;

use Zeedhi\ZhuAcl\Util\TableProperties;
use Zeedhi\ZhuAcl\Controller\ZhuCrud;
use Zeedhi\ZhuAcl\Service\AccessControlRule as AccessControlRuleService;
use Zeedhi\ZhuAcl\Model\Repositories\ZhuAccessControlElement;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class AccessControlRule extends ZhuCrud{

    /** @var ZhuAccessControlElement */
    protected $zhuAccessControlElementRepository;

    /** @var AccessControlRuleService */
    protected $accessControlRuleService;

    protected $dataSourceName = "aclZhuAccessControlRule";

    protected $parameterBagColumns = array(TableProperties::COLUMN_PROJECT_ID, TableProperties::COLUMN_GROUP_ID, TableProperties::COLUMN_ORGANIZATION_ID);

    public function __construct(Manager $dataSourceManager, ParameterBag $parameterBag, AccessControlRuleService $accessControlRuleService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->accessControlRuleService = $accessControlRuleService;
    }

    /**
     * @param $row
     * @return $containerRow
     */
    protected function prepareContainerRow($row){
        $containerRow = array(
            TableProperties::COLUMN_TYPE => TableProperties::TYPE_CONTAINER,
            TableProperties::COLUMN_UNIQUE_ID => $row[TableProperties::COLUMN_CONTAINER_ID],
            TableProperties::COLUMN_GROUP_ID => $row[TableProperties::COLUMN_GROUP_ID],
            TableProperties::COLUMN_NAME => $row[TableProperties::COLUMN_CONTAINER_NAME],
            TableProperties::COLUMN_LABEL => $row[TableProperties::COLUMN_CONTAINER_LABEL],
            TableProperties::COLUMN_PROJECT_ID => $row[TableProperties::COLUMN_PROJECT_ID],
            TableProperties::COLUMN_RULE => $row[TableProperties::COLUMN_RULE]
        );

        if(isset($row[TableProperties::COLUMN_CONTAINER_RULE_ID])){
            $containerRow[TableProperties::COLUMN_RULE_ID] = $row[TableProperties::COLUMN_CONTAINER_RULE_ID];
        }

        return $containerRow;
    }

    protected function saveContainerRule($row){
        $containerRow = $this->prepareContainerRow($row);
        $containerRule = $this->accessControlRuleService->insertRule($containerRow);
        return $containerRule;
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $updatedRules = array();
        $deletedRules = array();

        foreach($request->getDataSet()->getRows() as $row) {
            $uniqueId = $row[TableProperties::COLUMN_UNIQUE_ID];
            $hasContainerRule = isset($row[TableProperties::COLUMN_CONTAINER_ID]) && $row[TableProperties::COLUMN_TYPE] == TableProperties::TYPE_MENU;

            if(isset($row['__isDeleted']) && $row['__isDeleted']){
                $ruleId = $this->accessControlRuleService->deleteRule($row);
                if($ruleId){
                    array_push($deletedRules, $ruleId);
                }

                if($hasContainerRule && isset($row['RULE_SAVE_CONTAINER'])){
                    $row[TableProperties::COLUMN_RULE] = $row['RULE_SAVE_CONTAINER'];
                    $containerRule = $this->saveContainerRule($row);
                    $updatedRules[$uniqueId] = array(
                        "menuId" => $ruleId,
                        "containerId" => $containerRule->getId()
                    );
                }
            } else {
                $rule = $this->accessControlRuleService->insertRule($row);
                $ruleId = $rule->getId();

                if($hasContainerRule){
                    $containerRule = $this->saveContainerRule($row);
                    $updatedRules[$uniqueId] = array(
                        "menuId" => $ruleId,
                        "containerId" => $containerRule->getId()
                    );
                } else {
                    $updatedRules[$uniqueId] = $ruleId;
                }
            }
        }

        $modifiedRules = array("deleted"=> $deletedRules, "updated"=> $updatedRules);

        $rulesDataSet = new DataSet($this->dataSourceName, $modifiedRules);
        $response->addDataSet($rulesDataSet);
    }
}