CREATE OR REPLACE PROCEDURE ETL_ALTERPRODSAP
                           (P_DTINI      IN DATE,
                            P_DTFINA     IN DATE)
IS
   V_DTFIM      DATE;
   V_DTINI      DATE;
   V_MES           VARCHAR2(02);
   V_ANO           VARCHAR2(04);
   V_BIM           VARCHAR2(06);
   V_TRI           VARCHAR2(06);
   V_SEM           VARCHAR2(06);
   V_CDGOPERAC     VARCHAR2(12);
   V_CDSUPERVISOR  VARCHAR2(12);
   V_TIPOFATU      VARCHAR2(30);

   V_QTDEPOIS      FLOAT;    -- Quantidade depois da alterao
   V_QTDANTES      FLOAT;    -- Quantidade antes da alterao
   V_QTALTERAC     FLOAT;    -- Quantidade de alteraes realizadas

   V_QTDEPOIS_DRILL  FLOAT;    -- Quantidade depois da alterao
   V_QTDANTES_DRILL  FLOAT;    -- Quantidade antes da alterao
   V_QTALTERAC_DRILL FLOAT;    -- Quantidade de alteraes realizadas

BEGIN
   V_MES := TO_CHAR(P_DTINI,'MM');
   V_ANO := TO_CHAR(P_DTFINA, 'YYYY');
   DELETE FROM ETLALTERPRODSAP
    WHERE (CDANOBI > V_ANO)
       OR (CDANOBI = V_ANO AND CDMESBI >= V_MES);
   COMMIT;
   DELETE FROM ETLALTPRODDRILL
    WHERE (CDANOBI > V_ANO)
       OR (CDANOBI = V_ANO AND CDMESBI >= V_MES);
   COMMIT;
   V_DTINI := TO_DATE('01'||TO_CHAR(P_DTINI,'MMYYYY'),'DDMMYYYY');
   WHILE (V_DTINI  <=  P_DTFINA) LOOP
      V_MES := TO_CHAR(V_DTINI,'MM');
      V_ANO := TO_CHAR(P_DTFINA, 'YYYY');
      V_DTFIM := LAST_DAY(V_DTINI);
      V_BIM := TRUNC ((V_MES - 1) / 2) + 1;
      V_TRI := TRUNC ((V_MES - 1) / 3) + 1;
      V_SEM := TRUNC ((V_MES - 1) / 6) + 1;
      FOR C_ETL IN
         (SELECT F.CDFILIAL, CDEMPRESA,
                 F.CDAREAGERE    AS CDAREAGERE,
                 F.CDSEGMER      AS CDSEGMER,
                 F.DTINICIALBI   AS DTINICIALBI,
                 P.CDTIPOFATUR   AS CDTIPOFATUR
            FROM FILIAL F,  PARAMFILIAL P
           WHERE F.CDFILIAL = P.CDFILIAL
             AND F.IDFUNCAOFILI IS NULL
             AND F.DTINICIALBI IS NOT NULL
         )
      LOOP
         IF TO_DATE('01'||TO_CHAR(C_ETL.DTINICIALBI,'MMYYYY'),'DDMMYYYY') <= V_DTINI THEN
            V_TIPOFATU :=
            CASE  C_ETL.CDTIPOFATUR
              WHEN '001'  THEN   'Gesto Direta'
              WHEN '003'  THEN   'Mandato'
              WHEN '004'  THEN   'Refeies e Servios'
              WHEN '005'  THEN   'Taxa Fixa'
              WHEN '006'  THEN   'Gesto Hospitalar'
              WHEN '007'  THEN   'Produtos e Servios'
              WHEN '008'  THEN   'Produtos e Servios'
              ELSE 'Sem Tipo Faturamento'
            END;

            BEGIN
               SELECT MAX(CDGOPERACHIST), MAX(CDSUPERVHIST)
                 INTO V_CDGOPERAC, V_CDSUPERVISOR
                 FROM HISTFILIAL
                WHERE CDFILIAL = C_ETL.CDFILIAL
                  AND TRUNC(DTREFEHIST) BETWEEN V_DTINI AND V_DTFIM;
            EXCEPTION
                WHEN NO_DATA_FOUND THEN
                   V_CDGOPERAC    := NULL;
                   V_CDSUPERVISOR := NULL;
            END;

           /***********************
           *CURSOR DE ALTERAES *
           ***********************/
            FOR C_ALTER IN
               (SELECT MOV.CDPRODUTO, MOV.DTENTROPER, MOV.CDFILSOLMOV
                  FROM MOVOPSOL MOV
                 WHERE MOV.DTENTROPER BETWEEN V_DTINI AND V_DTFIM
                   AND CDFILSOLMOV = C_ETL.CDFILIAL
                 GROUP BY MOV.CDPRODUTO, MOV.DTENTROPER, MOV.CDFILSOLMOV
               )
            LOOP
               /*****************************************************************************
                * GRAVA A QUANTIDADE DE ALTERAES REALIZADAS PARA O PRODUTO/FILIAL/ENTREGA *
                *****************************************************************************/

               BEGIN
                 SELECT COUNT(DTOPERSOL) QTDALTER
                   INTO V_QTALTERAC
                   FROM MOVOPSOL
                  WHERE CDFILSOLMOV = C_ETL.CDFILIAL
                    AND DTENTROPER  = C_ALTER.DTENTROPER
                    AND CDPRODUTO   = C_ALTER.CDPRODUTO;
                 EXCEPTION
                    WHEN OTHERS THEN
                       V_QTALTERAC := 0;
               END;

               /****************************************************************
                * SELECT QUE GRAVA A QUANTIDADE ANTES PARA A PRIMEIRA ALTERAO*
                ****************************************************************/
               BEGIN
                 FOR C_QTDE_ANTES IN
                    (SELECT MIN(MOV.ROWID) ID
                      FROM MOVOPSOL MOV
                     WHERE MOV.CDFILSOLMOV = C_ETL.CDFILIAL
                       AND MOV.DTENTROPER  = C_ALTER.DTENTROPER
                       AND MOV.CDPRODUTO   = C_ALTER.CDPRODUTO
                       AND MOV.DTOPERSOL   = (SELECT MIN(DTOPERSOL)
                                                FROM MOVOPSOL
                                               WHERE CDFILSOLMOV = C_ETL.CDFILIAL
                                                 AND DTENTROPER  = C_ALTER.DTENTROPER
                                                 AND CDPRODUTO   = C_ALTER.CDPRODUTO))
                 LOOP
                    SELECT MIN(QTANTOPER)
                      INTO V_QTDANTES
                      FROM MOVOPSOL
                     WHERE MOVOPSOL.ROWID = C_QTDE_ANTES.ID;
                 END LOOP;
               EXCEPTION
                 WHEN OTHERS THEN
                    V_QTDANTES := 0;
               END;
               /***************************************************************
                * SELECT QUE GRAVA A QUANTIDADE DEPOIS PARA A LTIMA ALTERAO*
                ***************************************************************/
               BEGIN
                 FOR C_QTDE_DEPOIS IN
                    (SELECT MAX(MOV.ROWID) ID
                      FROM MOVOPSOL MOV
                     WHERE MOV.CDFILSOLMOV = C_ETL.CDFILIAL
                      AND MOV.DTENTROPER   = C_ALTER.DTENTROPER
                      AND MOV.CDPRODUTO    = C_ALTER.CDPRODUTO
                      AND MOV.DTOPERSOL    = (SELECT MAX(DTOPERSOL)  AS DTMINIALTER
                                                  FROM MOVOPSOL
                                                 WHERE CDFILSOLMOV  = C_ETL.CDFILIAL
                                                   AND DTENTROPER   = C_ALTER.DTENTROPER
                                                   AND CDPRODUTO    = C_ALTER.CDPRODUTO))
                 LOOP
                    SELECT MAX(QTDEPOPER)
                      INTO V_QTDEPOIS
                      FROM MOVOPSOL
                     WHERE MOVOPSOL.ROWID = C_QTDE_DEPOIS.ID;
                 END LOOP;
               EXCEPTION
                 WHEN OTHERS THEN BEGIN
                    V_QTDEPOIS := 0;
                 END;
               END;

               INSERT INTO ETLALTERPRODSAP
                 (CDEMPRESA,     CDAREAGERE,  CDSEGMER,    CDFILIAL,     CDOPERADOR,
                  CDTPFATU,      CDGOPERAC,   CDPRODUTO,   CDANOBI,      SEETLSAP,
                  TRETLSAP,      BIETLSAP,    CDMESBI,     QTDDEPOPER,   QTDANTOPER,
                  QTDTOTALTER,   DSDTALTERPROD)
               VALUES
                 (C_ETL.CDEMPRESA, C_ETL.CDAREAGERE, C_ETL.CDSEGMER,     C_ETL.CDFILIAL,  NULL,
                  V_TIPOFATU,      V_CDGOPERAC,      C_ALTER.CDPRODUTO,  V_ANO,           V_SEM,
                  V_TRI,           V_BIM,            V_MES,              V_QTDEPOIS,      V_QTDANTES,
                  V_QTALTERAC,     TO_CHAR(C_ALTER.DTENTROPER,'DD/MM/YYYY'));
               COMMIT;

               FOR C_ALTER_DRILL IN
                  (SELECT MOV.CDFILLANMOV, MOV.NRSOLIMOV, NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX') CDOPERADOR
                     FROM MOVOPSOL MOV
                    WHERE MOV.DTENTROPER = C_ALTER.DTENTROPER
                      AND MOV.CDFILSOLMOV = C_ETL.CDFILIAL
                      AND MOV.CDPRODUTO = C_ALTER.CDPRODUTO
                    GROUP BY MOV.CDFILLANMOV, MOV.NRSOLIMOV, NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX'))
               LOOP
                  /*************************************************************************
                  * GRAVA A QUANTIDADE DE ALTERAES REALIZADAS POR OPERADOR E SOLICITACAO *
                  **************************************************************************/
                  BEGIN
                    SELECT COUNT(DTOPERSOL) QTDALTER
                      INTO V_QTALTERAC_DRILL
                      FROM MOVOPSOL
                     WHERE CDFILSOLMOV = C_ETL.CDFILIAL
                       AND DTENTROPER  = C_ALTER.DTENTROPER
                       AND CDPRODUTO   = C_ALTER.CDPRODUTO
                       AND CDFILLANMOV = C_ALTER_DRILL.CDFILLANMOV
                       AND NRSOLIMOV   = C_ALTER_DRILL.NRSOLIMOV
                       AND NVL(CDOPERADOR, 'XXXXXXXXXXXX') = C_ALTER_DRILL.CDOPERADOR;
                    EXCEPTION
                       WHEN OTHERS THEN
                          V_QTALTERAC_DRILL := 0;
                  END;

                  /****************************************************************
                  * SELECT QUE GRAVA A QUANTIDADE ANTES PARA A PRIMEIRA ALTERAO*
                  * POR OPERADOR E SOLICITACAO                                   *
                  ****************************************************************/
                  BEGIN
                    FOR C_QTDE_ANTES_DRILL IN
                       (SELECT MIN(MOV.ROWID) ID
                         FROM MOVOPSOL MOV
                        WHERE MOV.CDFILSOLMOV = C_ETL.CDFILIAL
                          AND MOV.DTENTROPER  = C_ALTER.DTENTROPER
                          AND MOV.CDPRODUTO   = C_ALTER.CDPRODUTO
                          AND MOV.CDFILLANMOV = C_ALTER_DRILL.CDFILLANMOV
                          AND MOV.NRSOLIMOV   = C_ALTER_DRILL.NRSOLIMOV
                          AND NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX') = C_ALTER_DRILL.CDOPERADOR
                          AND MOV.DTOPERSOL   = (SELECT MIN(DTOPERSOL)
                                                   FROM MOVOPSOL
                                                  WHERE CDFILSOLMOV = C_ETL.CDFILIAL
                                                    AND DTENTROPER  = C_ALTER.DTENTROPER
                                                    AND CDPRODUTO   = C_ALTER.CDPRODUTO
                                                    AND CDFILLANMOV = C_ALTER_DRILL.CDFILLANMOV
                                                    AND NRSOLIMOV   = C_ALTER_DRILL.NRSOLIMOV
                                                    AND NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX') = C_ALTER_DRILL.CDOPERADOR))
                    LOOP
                       SELECT MIN(QTANTOPER)
                         INTO V_QTDANTES_DRILL
                         FROM MOVOPSOL
                        WHERE MOVOPSOL.ROWID = C_QTDE_ANTES_DRILL.ID;
                    END LOOP;
                  EXCEPTION
                     WHEN OTHERS THEN
                        V_QTDANTES_DRILL := 0;
                  END;
                  /***************************************************************
                   * SELECT QUE GRAVA A QUANTIDADE DEPOIS PARA A LTIMA ALTERAO*
                   * POR OPERADOR E SOLICITACAO                                  *
                   ***************************************************************/
                  BEGIN
                    FOR C_QTDE_DEPOIS_DRILL IN
                       (SELECT MAX(MOV.ROWID) ID
                         FROM MOVOPSOL MOV
                        WHERE MOV.CDFILSOLMOV = C_ETL.CDFILIAL
                         AND MOV.DTENTROPER   = C_ALTER.DTENTROPER
                         AND MOV.CDPRODUTO    = C_ALTER.CDPRODUTO
                         AND MOV.CDFILLANMOV  = C_ALTER_DRILL.CDFILLANMOV
                         AND MOV.NRSOLIMOV    = C_ALTER_DRILL.NRSOLIMOV
                         AND NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX') = C_ALTER_DRILL.CDOPERADOR
                         AND MOV.DTOPERSOL    = (SELECT MAX(DTOPERSOL)  AS DTMINIALTER
                                                     FROM MOVOPSOL
                                                    WHERE CDFILSOLMOV  = C_ETL.CDFILIAL
                                                      AND DTENTROPER   = C_ALTER.DTENTROPER
                                                      AND CDPRODUTO    = C_ALTER.CDPRODUTO
                                                      AND CDFILLANMOV  = C_ALTER_DRILL.CDFILLANMOV
                                                      AND NRSOLIMOV    = C_ALTER_DRILL.NRSOLIMOV
                                                      AND NVL(MOV.CDOPERADOR, 'XXXXXXXXXXXX') = C_ALTER_DRILL.CDOPERADOR))
                    LOOP
                       SELECT MAX(QTDEPOPER)
                         INTO V_QTDEPOIS_DRILL
                         FROM MOVOPSOL
                        WHERE MOVOPSOL.ROWID = C_QTDE_DEPOIS_DRILL.ID;
                    END LOOP;
                  EXCEPTION
                    WHEN OTHERS THEN BEGIN
                       V_QTDEPOIS_DRILL := 0;
                    END;
                  END;
                  INSERT INTO ETLALTPRODDRILL
                    (CDEMPRESA,     CDAREAGERE,  CDSEGMER,    CDFILIAL,     CDOPERADOR,
                     CDTPFATU,      CDGOPERAC,   CDPRODUTO,   CDANOBI,      SEETLSAP,
                     TRETLSAP,      BIETLSAP,    CDMESBI,     QTDDEPOPER,   QTDANTOPER,
                     QTDTOTALTER,   DSDTALTERPROD, CDFILIPROC, NRSOLIMOV)
                  VALUES
                    (C_ETL.CDEMPRESA, C_ETL.CDAREAGERE, C_ETL.CDSEGMER,     C_ETL.CDFILIAL,  C_ALTER_DRILL.CDOPERADOR,
                     V_TIPOFATU,      V_CDGOPERAC,      C_ALTER.CDPRODUTO,  V_ANO,           V_SEM,
                     V_TRI,           V_BIM,            V_MES,              V_QTDEPOIS_DRILL,      V_QTDANTES_DRILL,
                     V_QTALTERAC_DRILL, TO_CHAR(C_ALTER.DTENTROPER,'DD/MM/YYYY'), C_ALTER_DRILL.CDFILLANMOV, C_ALTER_DRILL.NRSOLIMOV);
                  COMMIT;
               --FIM LOOP C_ALTER_DRILL
               END LOOP;
            --FIM LOOP C_ALTER
            END LOOP;
         END IF;
      --FIM LOOP C_ETL
      END LOOP;
      V_DTINI := ADD_MONTHS(V_DTINI,1);
   --FIM LOOP POR DATA
   END LOOP;
END;
/

/*REGISTRANDO A PROCEDURE PARA O AGENDADOR DE EVENTOS*/
DECLARE
   V_CDSEQUENCIAL VARCHAR2(20) NULL;
BEGIN
   SELECT COUNT(*)
   INTO   V_CDSEQUENCIAL
   FROM   EVENTOAEV
   WHERE  NMOBJBDEVEN = 'ETL_ALTERPRODSAP';

   IF V_CDSEQUENCIAL = 0 THEN     --> S ADICIONA A PROCEDURE SE ELA NO EXISTIR AINDA NO CADASTRO
       BEGIN
           SELECT LPAD(NVL(MAX(LPAD(CDEVENTOAEV,10,'0'))+1,0),10,'0')
           INTO   V_CDSEQUENCIAL
           FROM   EVENTOAEV;

           INSERT INTO EVENTOAEV
           (CDEVENTOAEV, NMEVENTOAEV, IDTPEVENAEV, CDOPERINCL, DTINCLEVEN, NMOBJBDEVEN)
           VALUES
           (V_CDSEQUENCIAL,'Alteracoes em Solicitacao de Compras','STP',NULL,SYSDATE,'ETL_ALTERPRODSAP');

           INSERT INTO PARAMEVENTO
           (CDEVENTOAEV,NMPARAMEVEN,IDDADPARAMEVEN,IDTIPPARAMEVEN,DSPARAMEVEN,IDPARAMNULL,VRTAMPARAM,NRSEQPARAMEVEN)
           VALUES
           (V_CDSEQUENCIAL,'P_DTINI','D','E','Data Inicial','N',0,'01');

           INSERT INTO PARAMEVENTO
           (CDEVENTOAEV,NMPARAMEVEN,IDDADPARAMEVEN,IDTIPPARAMEVEN,DSPARAMEVEN,IDPARAMNULL,VRTAMPARAM,NRSEQPARAMEVEN)
           VALUES
           (V_CDSEQUENCIAL,'P_DTFINA','D','E','Data Final','N',0,'02');

           COMMIT;
       EXCEPTION
          WHEN OTHERS THEN
             RAISE_APPLICATION_ERROR (-20001,'Falha no cadastro de eventos agendveis.');
       END;
   END IF;
END;
/

/*REGISTRANDO FATOS E DIMENSES*/
BEGIN
   /*FATOS*/
   CRIA_FATOS('ETLALTERPRODSAP',       'QTDDEPOPER',   'Quantidade depois da alterao',        'Compras');
   CRIA_FATOS('ETLALTERPRODSAP',       'QTDANTOPER',   'Quantidade antes da alterao' ,        'Compras');
   CRIA_FATOS('ETLALTERPRODSAP',       'QTDTOTALTER',  'Quantidade de alteraes realizadas' ,  'Compras');

   CRIA_FATOS_DRILL('ETLALTPRODDRILL', 'QTDDEPOPER',   'Quantidade depois da alterao');
   CRIA_FATOS_DRILL('ETLALTPRODDRILL', 'QTDANTOPER',   'Quantidade antes da alterao');
   CRIA_FATOS_DRILL('ETLALTPRODDRILL', 'QTDTOTALTER',  'Quantidade de alteraes realizadas');

   /*DIMENSES*/
   CRIA_DIME('ETLALTERPRODSAP',       'CDEMPRESA',    'Empresa',             'EMPRESA',    'CDEMPRESA',    'NMEMPRESA',    NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDAREAGERE',   'Regional',            'AREAGERE',   'CDAREAGERE',   'NMAREAGERE',   NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDFILIAL',     'Filial',              'FILIAL',     'CDFILIAL',     'NMFILIAL',     NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDGOPERAC',    'Gerente Operacional', 'GOPERAC',    'CDGOPERAC',    'NMGOPERAC',    NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDPRODUTO',    'Produto',             'PRODUTO',    'CDPRODUTO',    'NMPRODUTO',    NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDANOBI',      'Ano',                 'ETLANOBI',   'CDANOBI',      'NMANOBI',      NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDMESBI',      'Ms',                 'ETLMESBI',   'CDMESBI',      'NMMESBI',      NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDSEGMER',     'Segmento de Mercado', 'SEGMERCADO', 'CDSEGMER',     'DSSEGMER',     NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'CDTPFATU',     'Tipo de Faturamento',  NULL,        NULL,           NULL,           NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'SEETLSAP',     'Bimestre',             NULL,        NULL,           NULL,           NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'TRETLSAP',     'Trimestre',            NULL,        NULL,           NULL,           NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'BIETLSAP',     'Semestre',             NULL,        NULL,           NULL,           NULL);
   CRIA_DIME('ETLALTERPRODSAP',       'DSDTALTERPROD','Entrega',              NULL,        NULL,           NULL,           NULL);

   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDEMPRESA',    'Empresa',             'EMPRESA',    'CDEMPRESA',    'NMEMPRESA',    NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDAREAGERE',   'Regional',            'AREAGERE',   'CDAREAGERE',   'NMAREAGERE',   NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDFILIAL',     'Filial',              'FILIAL',     'CDFILIAL',     'NMFILIAL',     NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDGOPERAC',    'Gerente Operacional', 'GOPERAC',    'CDGOPERAC',    'NMGOPERAC',    NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDPRODUTO',    'Produto',             'PRODUTO',    'CDPRODUTO',    'NMPRODUTO',    NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDANOBI',      'Ano',                 'ETLANOBI',   'CDANOBI',      'NMANOBI',      NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDMESBI',      'Ms',                 'ETLMESBI',   'CDMESBI',      'NMMESBI',      NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDSEGMER',     'Segmento de Mercado', 'SEGMERCADO', 'CDSEGMER',     'DSSEGMER',     NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDTPFATU',     'Tipo de Faturamento',  NULL,        NULL,           NULL,           NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'SEETLSAP',     'Bimestre',             NULL,        NULL,           NULL,           NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'TRETLSAP',     'Trimestre',            NULL,        NULL,           NULL,           NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'BIETLSAP',     'Semestre',             NULL,        NULL,           NULL,           NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'DSDTALTERPROD','Entrega',              NULL,        NULL,           NULL,           NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDOPERADOR',   'Operador',            'OPERADOR',  'CDOPERADOR',   'NMOPERADOR',    NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'CDFILIPROC',   'Filial Lan.',        'FILIAL',    'CDFILIAL',     'NMFILIAL',      NULL);
   CRIA_DIME_DRILL('ETLALTPRODDRILL', 'NRSOLIMOV',    'Solicitao',          NULL,        NULL,           NULL,           NULL);
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ETL_ALTERPRODSAP','5.05.111'); END;
/

