<?php
namespace Teknisa\Model\Gestaopessoas\Repositories;

use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\Repositories;

class GpeAltesitufunc extends \Doctrine\ORM\EntityRepository {
    
    public function retornaItem($nrvinculom, $nrorg) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $sql = <<<SQL
SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  ORDER BY a.dtinisitufunc
SQL;
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrvinculom
        );
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result;
    }
    
    public function retornaSituacaoFuncionalDentroPeriodo($nrorg, $nrvinculom, $dtIni, $DtFim) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $sql = <<<SQL
SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND (a.dtinisitufunc between :dtini and :dtfim or 
        a.dtfimsitufunc between :dtini and :dtfim
        or a.dtfimsitufunc is null)
        
  ORDER BY a.dtinisitufunc
SQL;
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrvinculom,
            'dtini' => $dtIni,
            'dtfim' => $DtFim
        );
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result;
    }
    
    public function retornaAlteSitFuncporVinculoNrsituacao($nrVinculom, $nrSituacao, $nrorg) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $sql = <<<SQL
SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND a.nrsitufuncm    = :nrsitufuncm
  ORDER BY a.dtinisitufunc DESC
SQL;
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrVinculom,
            'nrsitufuncm' => $nrSituacao
        );
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result;
    }
    
    public function retornaUltimaSituacaoPorDatainicio($nrorg, $nrvinculom, $dtinisitufunc) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        
        $sql = <<<SQL
SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND a.dtinisitufunc = (SELECT MAX(b.dtinisitufunc)
                           FROM $gpeAltesitufunc b
                          WHERE b.nrorg       = a.nrorg
                            AND b.nrvinculom  = a.nrvinculom
                            AND b.dtinisitufunc <= :dtinisitufunc)
SQL;
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrvinculom,
            'dtinisitufunc' => $dtinisitufunc
        );
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        
        return empty($result) ? $result : $result[0];
    }

    public function retornaProximaSituacaoPorDatainicio($nrorg, $nrvinculom, $dtinisitufunc, $nrproxsitufunc=null) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $sql = <<<SQL
SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND a.dtinisitufunc > :dtinisitufunc
  AND (a.nrsitufuncm = :nrsitufuncm OR :nrsitufuncm IS NULL)
SQL;
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrvinculom,
            'nrsitufuncm' => $nrproxsitufunc,
            'dtinisitufunc' => $dtinisitufunc
        );
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return empty($result) ? $result : $result[0];
    }

    public function retornaAlteSitFuncporVinculoNrcid($nr_vinculo,$nr_situacao,$nr_cid,$nr_org)
    {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $query = <<<SQL
SELECT a
FROM $gpeAltesitufunc a
WHERE a.nrvinculom = :p_nrvinculom
AND a.nrsitufuncm = :p_nrsitufuncm
AND a.cdtabecdi = :p_cdtabecdi
AND a.nrorg = :p_nrorg
SQL;
        $params = array(
            'p_nrvinculom'  => $nr_vinculo,
            'p_nrsitufuncm' => $nr_situacao,
            'p_cdtabecdi'   => $nr_cid,
            'p_nrorg'       => $nr_org,
        );

        return $this->getEntityManager()->createQuery($query)->execute($params);
    }
    
    public function getAfastamento($nrvinculom, $nrorg, $inicio, $final)
    {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $gpeSitufunc = Repositories::GPE_SITUFUNCH;
        $sql = <<<SQL
select SUBSTRING(sf.codrais, 3, 2) codrais,
    asf.dtinisitufunc,
    asf.dtfimsitufunc,
    asf.nrvinculom,
    asf.nrorg,
    asf.nrsitufuncm
from $gpeAltesitufunc asf
inner join $gpeSitufunc sf
    with sf.nrsitufuncm = asf.nrsitufuncm
where sf.nrsitufuncm in (14, 5, 3, 4, 2, 6, 7, 8, 11, 9)
    and asf.dtinisitufunc between :inicio and :final
    and asf.nrorg = :nrorg
    and asf.nrvinculom = :nrvinculom
order by asf.dtinisitufunc
SQL;
    $params = array(
        "inicio" => $inicio,
        "final" => $final,
        "nrorg" => $nrorg,
        "nrvinculom" => $nrvinculom
    );

        return $this->getEntityManager()->createQuery($sql)->execute($params);
        return ($result) ? $result : false;


    }

    public function getTotalAfastamento($nrvinculom, $nrorg, $inicio, $final) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $gpeSitufunc = Repositories::GPE_SITUFUNCH;
        $sql = <<<SQL
select sum((asf.dtfimsitufunc) - (asf.dtinisitufunc)) tempo,
    asf.nrvinculom,
    asf.nrorg

from $gpeAltesitufunc asf
inner join $gpeSitufunc sf
    with sf.nrsitufuncm = asf.nrsitufuncm
where sf.nrsitufuncm in (14, 5, 3, 4, 2, 6, 7, 8, 11, 9)
    and asf.dtinisitufunc between :inicio and :final
    and asf.nrorg = :nrorg
    and asf.nrvinculom = :nrvinculom
group by asf.nrvinculom,
    asf.nrorg
order by tempo
SQL;
        $params = array(
            "inicio" => $inicio,
            "final" => $final,
            "nrorg" => $nrorg,
            "nrvinculom" => $nrvinculom
        );

        return $this->getEntityManager()->createQuery($sql)->execute($params);
        return ($result) ? $result : false;

    }
    
    public function retornaUltimaSituacaoFuncional($nrorg, $nrvinculom, $dtinisitufunc) {
    
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
    
$sql = <<<SQL

SELECT a
  FROM $gpeAltesitufunc a
WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND a.dtinisitufunc = (SELECT MAX(b.dtinisitufunc)
                           FROM $gpeAltesitufunc b
                          WHERE b.nrorg       = a.nrorg
                            AND b.nrvinculom  = a.nrvinculom
                            AND b.dtinisitufunc <= :dtinisitufunc
                            )
SQL;
    
        $params = array(
            'nrorg' => $nrorg,
            'nrvinculom' => $nrvinculom,
            'dtinisitufunc' => $dtinisitufunc
        );
    
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return ($result) ? $result[0] : null;
    }
    
    public function retornaUltimoAfastamento($nrorg, $nrorgPadrao, $nrvinculom, $dtinisitufunc) {
    
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        $gpeSituFunch = Repositories::GPE_SITUFUNCH;
    
$sql = <<<SQL

SELECT a
  FROM $gpeAltesitufunc a
  
  inner join $gpeSituFunch sfh
    with sfh.nrsitufuncm = a.nrsitufuncm 
        and (sfh.nrorg = :nrorg or sfh.nrorg = :nrorg_padrao)

WHERE a.nrorg         = :nrorg
  AND a.nrvinculom    = :nrvinculom
  AND a.nrsitufuncm NOT IN (12, 15, 16, 13)
  AND sfh.idafastsitufunc = 'S'
  AND a.dtinisitufunc = (SELECT MAX(b.dtinisitufunc)
                           FROM $gpeAltesitufunc b
                          
                          inner join $gpeSituFunch d
                            with d.nrsitufuncm = a.nrsitufuncm 
                                and (d.nrorg = :nrorg or d.nrorg = :nrorg_padrao)
                           
                          WHERE b.nrorg       = a.nrorg
                            AND b.nrvinculom  = a.nrvinculom
                            AND d.idafastsitufunc = 'S'
                            AND b.nrsitufuncm = a.nrsitufuncm 
                            AND b.dtinisitufunc <= :dtinisitufunc
                            )
SQL;
    
        $params = array(
            'nrorg' => intval($nrorg),
            'nrorg_padrao'=> intval($nrorgPadrao),
            'nrvinculom' => $nrvinculom,
            'dtinisitufunc' => $dtinisitufunc
        );
    
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return ($result) ? $result[0] : null;
    }
    
    
    public function retornaSituacaoFuncional_AtesOuAfast($nrorg, $nrvinculom, $listNrsitufuncm, $iniPeriodo, $fimPeriodo, $id_Filtro) {
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
        
        $filtro1 = "";
        $filtro2 = "";

        if($id_Filtro === "ATESTADO")
            $filtro1 .= " AND a.nrsitufuncm IN (12, 15, 16) ";
        
        else if($id_Filtro === "AFASTAMENTO"){
            
            $filtro1  .= " AND a.nrsitufuncm NOT IN (12, 15, 16, 13) ";
            
            $filtro2 .= "
                OR (a.dtinisitufunc =  (SELECT MAX(maxA.dtinisitufunc)
                                        FROM $gpeAltesitufunc maxA
                                        WHERE maxA.nrorg = a.nrorg
                                            AND maxA.nrvinculom = a.nrvinculom
                                       ) 
                        $filtro1
                   )
            ";
        }    
        
        
$sql = <<<SQL

SELECT a
  FROM $gpeAltesitufunc a
 WHERE
    a.nrorg = :p_nrorg 
    AND a.nrvinculom = :p_nrvinculom 
    AND (
               (a.dtinisitufunc <= :p_fimPeriodo AND a.dtfimsitufunc >= :p_iniPeriodo $filtro1 )
            OR (a.dtinisitufunc BETWEEN :p_iniPeriodo AND :p_fimPeriodo $filtro1 )
            OR (a.dtfimsitufunc BETWEEN :p_iniPeriodo AND :p_fimPeriodo $filtro1 )
            OR (a.dtfimsitufunc IS NULL $filtro1) 
            $filtro2
        )
    AND a.nrsitufuncm IN ($listNrsitufuncm)    
SQL;
        $params = array(
            'p_nrorg'=>$nrorg, 
            'p_iniPeriodo'=>$iniPeriodo->format('d/m/Y'), 
            'p_fimPeriodo'=>$fimPeriodo->format('d/m/Y'), 
            'p_nrvinculom'=>$nrvinculom,
        );
        
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);

        return $result;        
    }    
    

    public function retornaProximaSituFuncional($nrorg, $nrVinculo, $dtinisitufunc, $fimPeriodo, $listNrsitufuncm){
    
        $gpeAltesitufunc = Repositories::GPE_ALTESITUFUNC;
    
$sql = <<<SQL

SELECT a
  FROM $gpeAltesitufunc a
 WHERE
    a.nrorg = :p_nrorg 
    AND a.nrvinculom = :p_nrvinculom 
    AND a.dtinisitufunc > :p_dtinisitufunc 
    AND a.dtinisitufunc <= :p_fimPeriodo
    AND a.nrsitufuncm NOT IN ($listNrsitufuncm)
SQL;

        $params = array(
            'p_nrorg'=>$nrorg, 
            'p_dtinisitufunc'=>$dtinisitufunc->format('d/m/Y'), 
            'p_fimPeriodo'=>$fimPeriodo->format('d/m/Y'), 
            'p_nrvinculom'=>$nrVinculo,
        );

        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result;        
    }
    
    public function getUltimaSituacaoFuncional($nrvinculom, $nrorg) {
        
        $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
        $params = array(
            "P_NRORG"       => $nrorg,
            "P_NRVINCULOM"  => $nrvinculom
        );
        
$sql = <<<SQL

SELECT * FROM (
SELECT NRVINCULOM,NRSITUFUNCM,
  DTINISITUFUNC,
  DTFIMSITUFUNC
FROM GPE_ALTESITUFUNC
WHERE 
  NRORG   = :P_NRORG
  AND NRVINCULOM = :P_NRVINCULOM
ORDER BY DTINISITUFUNC DESC, NRALTESITUFUNC DESC)
WHERE ROWNUM = 1
SQL;

        $result = $db->fetchAll($sql,$params);
        return !empty($result) ? $result : false;

    }

    public function getDiasSituacaoFuncional($nrvinculom, $nrorg, $inicio, $final, $nrsitufunc) {
        
        $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
        $params = array(
            "P_NRORG"       => $nrorg,
            "P_NRVINCULOM"  => $nrvinculom,
            "P_INICIO"      => $inicio,
            "P_FINAL"       => $final,
            "P_NRSITUFUNC"  => $nrsitufunc
        );
        
$sql = <<<SQL

 SELECT
  SUM((CASE WHEN GPE_ALTESITUFUNC.DTFIMSITUFUNC > TO_DATE(:P_FINAL)  THEN TO_DATE(:P_FINAL)  ELSE GPE_ALTESITUFUNC.DTFIMSITUFUNC END)
    - (CASE WHEN GPE_ALTESITUFUNC.DTINISITUFUNC < TO_DATE(:P_INICIO) THEN TO_DATE(:P_INICIO) ELSE GPE_ALTESITUFUNC.DTINISITUFUNC END)
      + 1) DIAS,
  GPE_ALTESITUFUNC.NRVINCULOM,
  GPE_ALTESITUFUNC.NRORG
FROM 
  GPE_ALTESITUFUNC
JOIN 
  GPE_SITUFUNCH ON GPE_SITUFUNCH.NRSITUFUNCM = GPE_ALTESITUFUNC.NRSITUFUNCM
WHERE 
  GPE_SITUFUNCH.NRSITUFUNCM = :P_NRSITUFUNC
  AND ((GPE_ALTESITUFUNC.DTINISITUFUNC BETWEEN TO_DATE(':P_INICIO') AND TO_DATE(':P_FINAL')) OR
      (GPE_ALTESITUFUNC.DTFIMSITUFUNC BETWEEN TO_DATE(':P_INICIO') AND TO_DATE(':P_FINAL')))
  AND GPE_ALTESITUFUNC.NRORG = :P_NRORG
      AND GPE_ALTESITUFUNC.NRVINCULOM = :P_NRVINCULOM
GROUP BY GPE_ALTESITUFUNC.NRVINCULOM, GPE_ALTESITUFUNC.NRORG
ORDER BY 1
SQL;
        $result = $db->fetchAll($sql,$params);
        return !empty($result) ? $result : false;
    }
}